<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:java="http://xml.apache.org/xslt/java"
				xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
				xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
				xmlns:op="utc.fr:ics/opale3"
				exclude-result-prefixes="sc sp op java">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />
	
    <xsl:template match="sc:uLink[not(@role)]">
    	<!-- UVED impose que @url commence par http:// ...  -->
    	<xsl:choose>
    		<xsl:when test="not(starts-with(@url, 'http://'))">
    			<xsl:value-of select="text()"/><xsl:text> (</xsl:text><xsl:value-of select="@url"/><xsl:text>)</xsl:text>
    		</xsl:when>
    		<xsl:otherwise>
    			<LIENWEB>
		            <xsl:attribute name="url"><xsl:value-of select="@url"/></xsl:attribute>
		            <xsl:value-of select="text()"/>
		        </LIENWEB>
    		</xsl:otherwise>
    	</xsl:choose>
    </xsl:template>
 
    <xsl:template match="sc:uLink[@role = 'acr']">
		<xsl:call-template name="tLogError">
            <xsl:with-param name="pMessage">Le concept d&apos;acronyme est absent d&apos;UVED. La récupération des acronymes est donc impossible.</xsl:with-param>
        </xsl:call-template>
        <I><xsl:apply-templates/></I>
    </xsl:template>
    
    <xsl:template match="sc:uLink[@role = 'glos']">
    	<!-- TODO : lever le mystére autour de LIENMOTDUGLOSSAIRE -->
    	<I><xsl:apply-templates/></I>
    	<MOTDUGLOSSAIRE mot="{getFullTitleText(gotoSubModel())}">
    		<xsl:value-of select="getContent(gotoSubModel(), 'texte')" disable-output-escaping="yes"/>
    	</MOTDUGLOSSAIRE>
    </xsl:template>
    
    <xsl:template match="sc:uLink[@role = 'bib']">
    	<xsl:variable name="vType" select="getFullTitleText(gotoSubModel(), 'biblio')"/>
    	<!-- TODO : lever le mystére autour de LIENREFERENCEBIBLIOGRAPHIQUE -->
    	<I><xsl:apply-templates/></I>
    	<xsl:choose>
    		<xsl:when test="$vType='web'">
    			<xsl:call-template name="tLogWarning">
					<xsl:with-param name="pMessage">Veuillez vérifier cette REFERENCEWEBOGRAPHIQUE (récupération potentiellement incomplète).</xsl:with-param>
				</xsl:call-template>
    			<REFERENCEWEBOGRAPHIQUE labelAdress="web-{gotoSubModel()}" URL="{normalize-space(getFullTitleText(gotoSubModel(), 'url'))}" auteurs="{normalize-space(getFullTitleText(gotoSubModel(), 'auth'))}" titre="{normalize-space(getFullTitleText(gotoSubModel(), ''))}" dateConsultation="{normalize-space(getFullTitleText(gotoSubModel(), 'date'))}">
    				<DESCRIPTION><xsl:value-of select="getContent(gotoSubModel(), 'cdata')" disable-output-escaping="yes"/></DESCRIPTION>
    			</REFERENCEWEBOGRAPHIQUE>
    		</xsl:when>
    		<xsl:otherwise>
    			<REFERENCEBIBLIOGRAPHIQUE labelReference="bib-{gotoSubModel()}"><!--labelReference : [0-9a-z-] dans UVED... -->
    				<xsl:value-of select="getContent(gotoSubModel(), 'biblio')" disable-output-escaping="yes"/>
    			</REFERENCEBIBLIOGRAPHIQUE>
    		</xsl:otherwise>
    	</xsl:choose>
        <xsl:call-template name="tLogWarning">
            <xsl:with-param name="pMessage">Incompatibilité de la structure de la bibliographie/webographie entre Opale et UVED. Une reprise manuelle est nécessaire.</xsl:with-param>
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template match="sc:uLink[@role = 'ref']">
    	<xsl:call-template name="tLogError">
			<xsl:with-param name="pMessage">Les &quot;références&quot; d&apos;Opale ne possèdent pas d&apos;équivalent dans UVED. Elles ont donc été ignorées.</xsl:with-param>
		</xsl:call-template>
        <I><xsl:apply-templates/></I>
    </xsl:template>
    
    <xsl:template match="sc:uLink[@role = 'resLnk' or @role = 'docLnk']">
		<xsl:variable name="vResPath" select="getContent(gotoSubModel(), 'page')"/>
		<xsl:choose>
        	<xsl:when test="$vResPath">
            	<LIENDOCUMENT url="{concat($vResDirName, extractFileNameFromPath($vResPath))}"><EM><xsl:value-of select="."/></EM></LIENDOCUMENT>
			</xsl:when>
			<xsl:otherwise>
				<EM><xsl:value-of select="."/></EM>
				<xsl:call-template name="tLogWarning">
					<xsl:with-param name="pMessage">Format de ressource non supporté : '<xsl:value-of select="@sc:refUri"/>'.</xsl:with-param>
				</xsl:call-template>
			</xsl:otherwise>
         </xsl:choose>
    </xsl:template>
    
    <!-- # InlineStyle -->
    <xsl:template match="sc:inlineStyle[@role='quote']">
        <xsl:text>"</xsl:text><xsl:apply-templates/><xsl:text>"</xsl:text>
    </xsl:template>
    
    <xsl:template match="sc:inlineStyle[@role='emp']">
        <EM><xsl:apply-templates/></EM>
    </xsl:template>
    
    <xsl:template match="sc:inlineStyle[@role='spec']">
        <I><xsl:apply-templates/></I>
    </xsl:template>
    
    <xsl:template match="sc:inlineStyle[@role='code']">
        <I><xsl:apply-templates/></I>
    </xsl:template>
    
    <!-- # TextLeaf -->
    <xsl:template match="sc:textLeaf[@role = 'exp']">
        <SUP><xsl:apply-templates/></SUP>
    </xsl:template>
    
    <xsl:template match="sc:textLeaf[@role = 'ind']">
        <SUB><xsl:apply-templates/></SUB>
    </xsl:template>
    
    <xsl:template match="sc:textLeaf[@role = 'mathtex']">
        <!-- TODO : preview PNG
    	<xsl:variable name="vResUri" select="resultatAgent('//', concat(	'resUri:src=src:', java:getSrcUri(srcFileAgent()), 
    	 																	';mutabledst=',resultatAgent('/@@/outTmpContent'),getDialogVar('child.path'),'/ressources/',java:getSrcName(srcFileAgent()),'.',generate-id(),'.png',
    	 																	';transform=latex2mathml&amp;omitXmlDeclaration=yes&amp;content=', java:java.net.URLEncoder.encode(java:replaceAll(string(.), '&amp;', '%26'), 'UTF-8'), '&amp;fileExt=.swf&amp;transform=mathml2mathmlOO&amp;transform=mml2png'))"/>
  		<EQUATEX texte="{.}" image="./ressources/{extractFileNameFromPath($vResUri)}"/>
  		 -->
  		 <EQUATEX texte="{.}"/>
    </xsl:template>
    
  	<!-- # InlineImg -->
    <xsl:template match="sc:inlineImg[@role = 'form']">
        <xsl:variable name="vType" select="typeAgent(concat('@', gotoSubModel()))"/>
        <xsl:choose>
        	<xsl:when test="contains($vType, 'mathTex')">
        		<EQUATEX texte="{getContent(gotoSubModel(), 'texte')}" image="./ressources/{extractFileNameFromPath(getContent(gotoSubModel(), 'page'))}"/>
        	</xsl:when>
        	<xsl:otherwise>
        		<xsl:call-template name="tLogWarning">
					<xsl:with-param name="pMessage">Les équation inline de type MathML et/ou ODF ne sont pas autorisées dans UVED et seront donc affichées aprés le paragraphe ou la liste.</xsl:with-param>
				</xsl:call-template>
        	</xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="sc:inlineImg[@role = 'form']" mode="afterPara">
        <xsl:variable name="vType" select="typeAgent(concat('@', gotoSubModel()))"/>
        <xsl:choose>
        	<xsl:when test="contains($vType, 'mathTex')"><!-- déja affiché dans le texte --></xsl:when>
        	<xsl:otherwise>
        		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
        	</xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="sc:inlineImg[@role = 'ico']">
       <xsl:call-template name="tLogWarning">
			<xsl:with-param name="pMessage">Les imagettes dans le texte ne sont pas gérées dans UVED et seront donc affichées aprés le paragraphe ou la liste.</xsl:with-param>
		</xsl:call-template>
    </xsl:template>
    <xsl:template match="sc:inlineImg[@role = 'ico']" mode="afterPara">
       <xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
    </xsl:template>
    
	
	 
</xsl:stylesheet>
