<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
				xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
				xmlns:op="utc.fr:ics/opale3"
				exclude-result-prefixes="sc sp op">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />
	
	<xsl:variable name="vCurrentPath" select="getDialogVar('child.path')"/>
	<xsl:variable name="vCurrentId" select="getDialogVar('child.id')"/>
	<xsl:variable name="vResDirName">./ressources/</xsl:variable>
		
	<!-- # Gestion des éléments de structure -->
	<xsl:template match="sp:courseUa | sp:assmntUa | sp:div" name="tStruct">
		<xsl:variable name="vChildId" select="translate(gotoSubModel(),'_','-')"/>
		<xsl:variable name="vChildPath" select="concat($vCurrentPath, '/', $vChildId)"/>
		<xsl:value-of select="execute(setDialogVar('child.id', $vChildId))"/>
		<xsl:choose>
			<xsl:when test="@sc:refUri">
				<REFSECTION label="{$vChildId}"/>
				<!-- Renseignement des variables d'identification de l'élément fils -->
				<xsl:value-of select="execute(setDialogVar('child.path', $vChildPath))"/>
				<!-- Création du fichier fils -->
				<xsl:value-of select="execute(getContent(gotoSubModel(), 'page'))"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- méta non autorisées à cet endroit dans UVED -->	
				<xsl:value-of select="getContent(gotoMeta(gotoSubModel()), 'notRecovered')" disable-output-escaping="yes" />
				<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />	
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- Grains tjs internalisés -->
	<xsl:template match="sp:courseUc | sp:practUc | sp:trainUc" name="tGetGrain">
		<xsl:variable name="vChildId" select="translate(gotoSubModel(),'_','-')"/>
		<xsl:value-of select="execute(setDialogVar('child.id', $vChildId))"/>
		<xsl:value-of select="getContent(gotoMeta(gotoSubModel()), 'notRecovered')" disable-output-escaping="yes" />
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>
	
	<!-- # Références générales -->
	<xsl:template match="sp:genRef">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>
	
	<!-- # Traitement par défaut des balises -->
	<xsl:template match="op:ueDivM | op:uM">
		<xsl:if test="count(*[name()!='sp:title'])">
			<xsl:call-template name="tNoTranslated"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="*" name="tNoTranslated">
		<xsl:call-template name="tLogInfo">
			<xsl:with-param name="pMessage">Elément non récupéré automatiquement lors de la migration vers Opale : '<xsl:value-of select="local-name()"/>'
			Ce contenu a donc été ignoré : '<xsl:value-of select="."/>';
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
</xsl:stylesheet>
