<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
				xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" 
				xmlns:op="utc.fr:ics/opale3"
				exclude-result-prefixes="sc sp op">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />
	
	<xsl:include href="bsco:export.xsl" />
	<xsl:include href="bsco:uved.xsl" />

	<xsl:template match="op:bib">
		<xsl:apply-templates select="op:bibM/sp:desc"/>
	</xsl:template>
	
	<xsl:template match="sp:desc">
		<REFOUVRAGE>
			<xsl:attribute name="titre">
				<xsl:value-of select=".//sc:textLeaf[@role = 'title'][1]"/>
				<xsl:if test="not(.//sc:textLeaf[@role = 'title'])">
					<xsl:call-template name="tLogError">
						<xsl:with-param name="pMessage">Un REFOUVRAGE doit posséder obligatoirement un &apos;titre&apos; dans UVED.</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:attribute>
			<xsl:attribute name="premierAuteur">
				<xsl:value-of select=".//sc:textLeaf[@role = 'auth'][1]"/>
				<xsl:if test="not(.//sc:textLeaf[@role = 'auth'])">
					<xsl:call-template name="tLogError">
						<xsl:with-param name="pMessage">Un REFOUVRAGE doit posséder obligatoirement un &apos;premierAuteur&apos; dans UVED.</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:attribute>
			<xsl:if test="count(.//sc:textLeaf[@role = 'auth'])&gt;1">
				<xsl:attribute name="autresAuteurs">
					<xsl:for-each select=".//sc:textLeaf[@role = 'auth'][count(preceding-sibling::sc:textLeaf[@role = 'auth'])&gt;0]"><xsl:value-of select="."/></xsl:for-each>
				</xsl:attribute>
			</xsl:if>
			<xsl:attribute name="annee">
				<xsl:choose>
					<xsl:when test=".//sc:textLeaf[@role = 'date']">
						<xsl:call-template name="tLogError">
							<xsl:with-param name="pMessage">Veuillez vérifier la cohérence entre le champs &apos;date&apos; d&apos;Opale et le champs &apos;année&apos; d&apos;UVED qui doit respecter la syntaxe : XXXX.</xsl:with-param>
						</xsl:call-template>
						<xsl:value-of select=".//sc:textLeaf[@role = 'date'][1]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="tLogError">
							<xsl:with-param name="pMessage">Un REFOUVRAGE doit posséder obligatoirement une &apos;année&apos; dans UVED.</xsl:with-param>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="editeur">
				<xsl:value-of select=".//sc:textLeaf[@role = 'ed'][1]"/>
				<xsl:if test="not(.//sc:textLeaf[@role = 'ed'])">
					<xsl:call-template name="tLogError">
						<xsl:with-param name="pMessage">Un REFOUVRAGE doit posséder obligatoirement une &apos;editeur&apos; dans UVED.</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:attribute>
			<xsl:if test=".//sc:uLink[@role = 'url']">
				<xsl:attribute name="url"><xsl:value-of select=".//sc:uLink[@role = 'url'][1]"/></xsl:attribute>
			</xsl:if>
		</REFOUVRAGE>
	</xsl:template>
			
</xsl:stylesheet>




