<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
				xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" 
				xmlns:op="utc.fr:ics/opale3"
				exclude-result-prefixes="sc sp op">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />
	
	<xsl:include href="bsco:export.xsl" />
	<xsl:include href="bsco:uved.xsl" />

	<xsl:template match="op:expUc | op:practUc | op:trainUc">
		<GRAIN titre="{op:uM/sp:title}" label="{$vCurrentId}">
			<xsl:apply-templates select="*[name()!='op:uM']"/>
		</GRAIN>
	</xsl:template>
		
	<xsl:template match="sp:pb">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>
	
	<xsl:template match="sp:div">
		<!-- UVED : pas de concepts de division dans un grain => reconstitution applatie de la structure -->
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="op:expUcDiv">
		<xsl:variable name="vCurrent" select=".."/>
		<xsl:variable name="vNumber">
			<xsl:for-each select="ancestor::sp:div">
				<xsl:value-of select="count(preceding-sibling::sp:div) + 1"/><xsl:if test=".!=$vCurrent">.</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<PARAGRAPHE><B><xsl:value-of select="$vNumber"/> - <xsl:value-of select="op:expUcDivM/sp:title"/></B></PARAGRAPHE>
		<xsl:apply-templates select="*[name()!='op:expUcDivM']"/>
	</xsl:template>
	
	<xsl:template match="sp:desc">
		<xsl:variable name="vDefaultTitle">
			<xsl:apply-templates select="." mode="label"/>
		</xsl:variable>
		<PARAGRAPHE>
			<B><xsl:value-of select="si(op:sTitle/sc:fullTitle, op:sTitle/sc:fullTitle, $vDefaultTitle)"/></B>
		</PARAGRAPHE>
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>
	
	<!-- # op:practUc -->
	<xsl:template match="sp:quest">
		<EXERCICE>
			<QUESTION>
				<xsl:apply-templates select="op:practUcQ/*[name()!='sp:sol']"/>
				<xsl:if test="op:practUcQ/sp:sol"><!-- Une seule solution dans UVED -->
					<SOLUTION>
						<xsl:apply-templates select="op:practUcQ/sp:sol"/>
					</SOLUTION>
				</xsl:if>
			</QUESTION>
		</EXERCICE>
	</xsl:template>
	<xsl:template match="op:practUcQ/sp:desc">
		<ENONCE>
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</ENONCE>
	</xsl:template>
	<xsl:template match="sp:hint">
		<AIDE>
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</AIDE>
	</xsl:template>
	<xsl:template match="sp:sol">
		<xsl:value-of select="getContent(gotoSubModel(), 'para')" disable-output-escaping="yes" />
	</xsl:template>
	
	<!-- # op:trainUc -->
	<xsl:template match="op:quiz">
		<xsl:call-template name="tLogInfo">
			<xsl:with-param name="pMessage">Exercice intéractif récupéré de façon incomplète</xsl:with-param>
		</xsl:call-template>
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>
	

	<!-- Elements non gérés :
			- uM	
	-->

</xsl:stylesheet>





