<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
				xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" 
				xmlns:op="utc.fr:ics/opale3"
				exclude-result-prefixes="sc sp op">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />
	
	<xsl:include href="bsco:export.xsl" />
	<xsl:include href="bsco:uved.xsl" />
	<xsl:include href="bsco:uved.txt.inline.xsl" />

	<xsl:template match="op:sPara | op:sTxt | op:txt | op:qTxt">
		<xsl:apply-templates/>
	</xsl:template>
	
	<!-- # Paragraphes -->
	<xsl:template match="sc:para">
		<xsl:if test="count(preceding-sibling::*)!=0"><BR/></xsl:if><xsl:apply-templates/>
	</xsl:template>
	
	<!-- # Listes -->
	<xsl:template match="sc:itemizedList">
		<xsl:if test="count(preceding-sibling::*)!=0"><BR/></xsl:if>
		<xsl:apply-templates select="sc:listItem" mode="itemized"/>
	</xsl:template>
	<xsl:template match="sc:orderedList">
		<xsl:if test="count(preceding-sibling::*)!=0"><BR/></xsl:if>
		<xsl:apply-templates select="sc:listItem" mode="ordered"/>
	</xsl:template>
	
	<xsl:template match="sc:listItem" mode="itemized">
		<xsl:variable name="vLevel"><xsl:call-template name="tGetLevel"/></xsl:variable>
		<xsl:choose>
			<xsl:when test="$vLevel=1">*<NBSP/></xsl:when>
			<xsl:when test="$vLevel=2">**<NBSP/></xsl:when>
			<xsl:when test="$vLevel=3">***<NBSP/></xsl:when>
			<xsl:otherwise>****<NBSP/></xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="sc:listItem" mode="ordered">
		<xsl:variable name="vLevel"><xsl:call-template name="tGetLevel"/></xsl:variable>
		<xsl:variable name="vPosition" select="count(preceding-sibling::sc:listItem[name(..)='sc:orderedList' ])+1"/>
		<xsl:choose>
			<xsl:when test="$vLevel=1"><xsl:number value="$vPosition" format="1"/>.&#160;</xsl:when>
			<xsl:when test="$vLevel=2"><xsl:number value="$vPosition" format="1"/>.&#160;</xsl:when>
			<xsl:when test="$vLevel=3"><xsl:number value="$vPosition" format="a"/>)&#160;</xsl:when>
			<xsl:otherwise><xsl:number value="$vPosition" format="i"/>-&#160;</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template name="tGetLevel">
		<!-- level = [2,3,4]-->
		<xsl:value-of select="max(min(count(ancestor-or-self::*[name()='sc:listItem' or name()='sc:member'])+1, 4), 2)"/>
	</xsl:template>
	
</xsl:stylesheet>



